==> xscreensaver_4.21.orig.tar.gz: xscreensaver-4.21/hacks/glx/toaster_wing.c <==
#include "gllist.h"
static float data[]={
	-0.002931,-0.001173,-0.999995,0.5,-0.248054,-0.034832,
	-0.002931,-0.001173,-0.999995,-0.5,0.248054,-0.032483,
	-0.002931,-0.001173,-0.999995,0.399306,0.003521,-0.034832,
	0.189903,0.691703,0.696767,0.399306,0.003521,-0.034832,
	0.189903,0.691703,0.696767,-0.5,0.248054,-0.032483,
	0.189903,0.691703,0.696767,0.3827,-0.039065,0.01197,
	-0.035459,-0.237307,0.970787,0.5,-0.248054,-0.034832,
	-0.035459,-0.237307,0.970787,0.3827,-0.039065,0.01197,
	-0.035459,-0.237307,0.970787,-0.466673,-0.094003,-0.032483,
	-0.002468,-0.00024,-0.999997,0.5,-0.248054,-0.034832,
	-0.002468,-0.00024,-0.999997,-0.466673,-0.094003,-0.032483,
	-0.002468,-0.00024,-0.999997,-0.5,0.248054,-0.032483,
	-0.051938,-0.00506,0.998637,0.3827,-0.039065,0.01197,
	-0.051938,-0.00506,0.998637,-0.5,0.248054,-0.032483,
	-0.051938,-0.00506,0.998637,-0.466673,-0.094003,-0.032483,
	-0.031687,-0.285224,0.957937,0.3827,-0.039065,0.01197,
	-0.031687,-0.285224,0.957937,-0.482606,0.13385,0.034832,
	-0.031687,-0.285224,0.957937,-0.466673,-0.094003,-0.032483,
	0.370589,0,0.928797,0.5,-0.065307,-0.034832,
	0.370589,0,0.928797,0.3827,-0.039065,0.01197,
	0.370589,0,0.928797,0.5,-0.248054,-0.034832,
	0.125848,0.517903,0.846131,0.3827,-0.039065,0.01197,
	0.125848,0.517903,0.846131,-0.5,0.248054,-0.032483,
	0.125848,0.517903,0.846131,-0.482606,0.13385,0.034832,
	-0.772167,-0.309062,-0.555193,0.399306,0.003521,-0.034832,
	-0.772167,-0.309062,-0.555193,0.5,-0.248054,-0.034832,
	-0.772167,-0.309062,-0.555193,0.3827,-0.039065,0.01197,
	0.408832,0.598113,0.689287,0.5,-0.065307,-0.034832,
	0.408832,0.598113,0.689287,0.399306,0.003521,-0.034832,
	0.408832,0.598113,0.689287,0.3827,-0.039065,0.01197,
	0,0,-1,0.5,-0.248054,-0.034832,
	0,0,-1,0.399306,0.003521,-0.034832,
	0,0,-1,0.5,-0.065307,-0.034832
};
static struct gllist frame={GL_N3F_V3F,GL_TRIANGLES,33,data,NULL};
struct gllist *toaster_wing=&frame;

==> xscreensaver_5.15.orig.tar.gz: xscreensaver-5.15/hacks/glx/toaster_wing.c <==
#include "gllist.h"
static const float data[]={
	-0.002931,-0.001173,-0.999995,0.5,-0.248054,-0.034832,
	-0.002931,-0.001173,-0.999995,-0.5,0.248054,-0.032483,
	-0.002931,-0.001173,-0.999995,0.399306,0.003521,-0.034832,
	0.189903,0.691703,0.696767,0.399306,0.003521,-0.034832,
	0.189903,0.691703,0.696767,-0.5,0.248054,-0.032483,
	0.189903,0.691703,0.696767,0.3827,-0.039065,0.01197,
	-0.035459,-0.237307,0.970787,0.5,-0.248054,-0.034832,
	-0.035459,-0.237307,0.970787,0.3827,-0.039065,0.01197,
	-0.035459,-0.237307,0.970787,-0.466673,-0.094003,-0.032483,
	-0.002468,-0.00024,-0.999997,0.5,-0.248054,-0.034832,
	-0.002468,-0.00024,-0.999997,-0.466673,-0.094003,-0.032483,
	-0.002468,-0.00024,-0.999997,-0.5,0.248054,-0.032483,
	-0.051938,-0.00506,0.998637,0.3827,-0.039065,0.01197,
	-0.051938,-0.00506,0.998637,-0.5,0.248054,-0.032483,
	-0.051938,-0.00506,0.998637,-0.466673,-0.094003,-0.032483,
	-0.031687,-0.285224,0.957937,0.3827,-0.039065,0.01197,
	-0.031687,-0.285224,0.957937,-0.482606,0.13385,0.034832,
	-0.031687,-0.285224,0.957937,-0.466673,-0.094003,-0.032483,
	0.370589,0,0.928797,0.5,-0.065307,-0.034832,
	0.370589,0,0.928797,0.3827,-0.039065,0.01197,
	0.370589,0,0.928797,0.5,-0.248054,-0.034832,
	0.125848,0.517903,0.846131,0.3827,-0.039065,0.01197,
	0.125848,0.517903,0.846131,-0.5,0.248054,-0.032483,
	0.125848,0.517903,0.846131,-0.482606,0.13385,0.034832,
	-0.772167,-0.309062,-0.555193,0.399306,0.003521,-0.034832,
	-0.772167,-0.309062,-0.555193,0.5,-0.248054,-0.034832,
	-0.772167,-0.309062,-0.555193,0.3827,-0.039065,0.01197,
	0.408832,0.598113,0.689287,0.5,-0.065307,-0.034832,
	0.408832,0.598113,0.689287,0.399306,0.003521,-0.034832,
	0.408832,0.598113,0.689287,0.3827,-0.039065,0.01197,
	0,0,-1,0.5,-0.248054,-0.034832,
	0,0,-1,0.399306,0.003521,-0.034832,
	0,0,-1,0.5,-0.065307,-0.034832
};
static const struct gllist frame={GL_N3F_V3F,GL_TRIANGLES,33,data,NULL};
const struct gllist *toaster_wing=&frame;
